Learn R Programming

Rosenbrock (version 0.1.0)

dhybrid: Density Function "Hybrid Rosenbrock Function"

Description

Density function for the hybrid rosenbrock function, with two list of vectors parameters b and input x/ xprime.

Usage

dhybrid(xprime,x,a,b,mu)

Arguments

xprime

Central input.

x

List of input vector blocks.

mu

Density shift.

a

Parameters for xprime.

b

List of parameters corresponding to input blocks.

Value

Returns the density value of the "hybrid" Rosenbrock distribution at point x/xprime for parameters mu,a and b.

Examples

Run this code
# NOT RUN {
a <- 1
xprime <- 1
mu <- - 1

x <- list(c(1,2),
          c(2,3))

b <- list(c(3,2),
          c(2,2))

dhybrid(xprime = xprime,x = x,a = a,b = b,mu = mu)
# }

Run the code above in your browser using DataLab