Learn R Programming

Rosenbrock (version 0.1.0)

reven: Random Sampler for the "Even Rosenbrock Function"

Description

Random sampler for the full Rosenbrock function, with two vector parameters a and b.

Usage

reven(n,a,b,mu)

Arguments

n

Sample size.

mu

Density shift.

a

Parameters for odd index input.

b

Parameters for even index input.

Value

Returns a sample of size n from the "full" Rosenbrock distribution.

Examples

Run this code
# NOT RUN {
n = 100
a = b = rep(2,2)
mu = rep(1,2)

reven(n = n,mu = mu,a = a,b = b)
# }

Run the code above in your browser using DataLab