Learn R Programming

Rosenbrock (version 0.1.0)

rhybrid: Random Sampler for the "Hybrid Rosenbrock Function"

Description

Random Sampler for the hybrid rosenbrock function, with two list of vectors parameters b and input x/ xprime.

Usage

rhybrid(n,a,b,mu)

Arguments

n

Sample size.

mu

Density shift.

a

Parameters for xprime.

b

List of parameters corresponding to input blocks.

Value

Returns a sample of size n from the "hybrid" Rosenbrock distribution.

Examples

Run this code
# NOT RUN {
a <- 1
mu <- - 1

b <- list(c(3,2),
          c(2,2))

n <- 100

rhybrid(n = n,a = a,b = b,mu = mu)
# }

Run the code above in your browser using DataLab