powered by
Density function for the hybrid rosenbrock function, with two list of vectors parameters b and input x/ xprime.
dhybrid(xprime,x,a,b,mu)
Central input.
List of input vector blocks.
Density shift.
Parameters for xprime.
List of parameters corresponding to input blocks.
Returns the density value of the "hybrid" Rosenbrock distribution at point x/xprime for parameters mu,a and b.
x
xprime
mu,a
b
# NOT RUN { a <- 1 xprime <- 1 mu <- - 1 x <- list(c(1,2), c(2,3)) b <- list(c(3,2), c(2,2)) dhybrid(xprime = xprime,x = x,a = a,b = b,mu = mu) # }
Run the code above in your browser using DataLab