powered by
Random sampler for the full Rosenbrock function, with two vector parameters a and b.
reven(n,a,b,mu)
Sample size.
Density shift.
Parameters for odd index input.
Parameters for even index input.
Returns a sample of size n from the "full" Rosenbrock distribution.
n
# NOT RUN { n = 100 a = b = rep(2,2) mu = rep(1,2) reven(n = n,mu = mu,a = a,b = b) # }
Run the code above in your browser using DataLab