powered by
Random Sampler for the hybrid rosenbrock function, with two list of vectors parameters b and input x/ xprime.
rhybrid(n,a,b,mu)
Sample size.
Density shift.
Parameters for xprime.
List of parameters corresponding to input blocks.
Returns a sample of size n from the "hybrid" Rosenbrock distribution.
n
# NOT RUN { a <- 1 mu <- - 1 b <- list(c(3,2), c(2,2)) n <- 100 rhybrid(n = n,a = a,b = b,mu = mu) # }
Run the code above in your browser using DataLab